# Automatic discard detection and tracking

This repository contains the code beloning to the paper "Automatic discard registration in cluttered environments using deep learning and object tracking: class imbalance, occlusion, and a comparison to human review". If you find this code usefull, please consider citing our paper.

The dataset belonging to this repository can be found at https://dx.doi.org/10.4121/1662256.


## Installation
Clone the repository from GIT including the submodules:

```commandline
git clone https://github.com/Rick-v-E/automatic_discard_registration
```

### Requirements
Python 3.8 is needed with all [requirements.txt](requirements.txt) dependencies as well as the YOLOv3 [requirements.txt](detection/yolov3/requirements.txt) installed. Optionally, apex can be installed for faster training:

```commandline
pip install -r requirements.txt
pip install -r detection/yolov3/requirements.txt
pip install detection/apex
```

## Content
The software contains 5 notebooks:


| Notebook                               |                         | Description                                                                          |
|----------------------------------------|-------------------------|--------------------------------------------------------------------------------------|
| [create_dataset](create_dataset.ipynb) | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/Rick-v-E/automatic_discard_registration/blob/master/create_dataset.ipynb) | Notebook to download the dataset from the data repository and create synthetic data. |
| [train](train.ipynb)                   | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/Rick-v-E/automatic_discard_registration/blob/master/notebooks/train.ipynb) | Notebook to train the YOLOv3 neural network.                                         |
| [detect](detect.ipynb)                   | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/Rick-v-E/automatic_discard_registration/blob/master/notebooks/detect.ipynb) | Notebook to detect fishes in the images.                                         |
| [track](track.ipynb)                   | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/Rick-v-E/automatic_discard_registration/blob/master/notebooks/ctrack.ipynb) | Notebook to track the fishes over consequtive images.    |
| [evaluate](evaluate.ipynb)             | [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/Rick-v-E/automatic_discard_registration/blob/master/notebooks/evaluate.ipynb) | Notebook to evaluate the detection and count the number of tracked fishes.           |
